@@ -8,7 +8,7 @@ import re
 import pymongo
 import pandas as pd
 from util_hj3415 import utils
-from .setting import load as load_setting
+from .setting import load as load_setting, is_srv_live, chg_mongo_addr
 from collections import OrderedDict
 from typing import Tuple
 
@@ -20,8 +20,6 @@ ch.setFormatter(formatter)
 logger.addHandler(ch)
 logger.setLevel(logging.WARNING)
 
-mongo_addr = load_setting().mongo_addr
-
 
 def chk_deactivate_mongo(func):
     """
@@ -37,13 +35,19 @@ def chk_deactivate_mongo(func):
     return wrapper
 
 
+class MongoNotResponseError(Exception):
+    pass
+
+
 class Base:
     def __init__(self, db, col):
-        self.mongo_addr = load_setting().mongo_addr
+        setting = load_setting()
+        if not is_srv_live(setting.mongo_addr):
+            raise MongoNotResponseError(setting.mongo_addr)
 
         # mongodb 에 연결
-        if load_setting().active_mongo:
-            self.client = pymongo.MongoClient(self.mongo_addr)
+        if setting.active_mongo:
+            self.client = pymongo.MongoClient(setting.mongo_addr)
             self.db = db
             self.col = col
             logger.info(f"__init__ set db : {self.db}\tcol : {self.col}")
@@ -63,7 +67,8 @@ class Base:
         Examples:
             ('005930', 'c103재무상태표q')
         """
-        return self.mongo_addr, self.db, self.col
+        setting = load_setting()
+        return setting.mongo_addr, self.db, self.col
 
     def chg_addr(self, addr: str):
         """
@@ -80,8 +85,9 @@ class Base:
         if not addr.startswith('mongodb://'):
             raise ValueError(f'Invalid mongo address : {addr}')
         else:
-            logger.info(f'Set addr : {self.mongo_addr} -> {addr}')
-            self.mongo_addr = addr
+            setting = load_setting()
+            logger.info(f'Set addr : {setting.mongo_addr} -> {addr}')
+            chg_mongo_addr(addr)
             self.client = pymongo.MongoClient(addr)
 
     # ======================상속 클래스에서 재구성할 수 있는 함수들================
@@ -90,13 +96,15 @@ class Base:
     @staticmethod
     @chk_deactivate_mongo
     def get_all_db() -> list:
-        client = pymongo.MongoClient(mongo_addr)
+        setting = load_setting()
+        client = pymongo.MongoClient(setting.mongo_addr)
         return sorted(client.list_database_names())
 
     @staticmethod
     @chk_deactivate_mongo
     def drop_all_db():
-        client = pymongo.MongoClient(mongo_addr)
+        setting = load_setting()
+        client = pymongo.MongoClient(setting.mongo_addr)
         pre_db = Base.get_all_db()
         for db in pre_db:
             client.drop_database(db)
@@ -106,7 +114,8 @@ class Base:
     @staticmethod
     @chk_deactivate_mongo
     def drop_db(db: str):
-        client = pymongo.MongoClient(mongo_addr)
+        setting = load_setting()
+        client = pymongo.MongoClient(setting.mongo_addr)
         pre_db = Base.get_all_db()
         if db in pre_db:
             client.drop_database(db)
@@ -337,7 +346,8 @@ class Corps(Base):
 
     @staticmethod
     def drop_all_corps():
-        client = pymongo.MongoClient(mongo_addr)
+        setting = load_setting()
+        client = pymongo.MongoClient(setting.mongo_addr)
         pre_db = Corps.get_all_corps()
         for db in pre_db:
             client.drop_database(db)
@@ -629,8 +639,9 @@ class C106(Corps):
 
         c106컬렉션에서 title이 c106y 또는 c106q가 아닌 도큐먼트가 저장되어 있으면 찾아내서 삭제함.
         """
-        client = pymongo.MongoClient(mongo_addr)
-        print(f"Mongo addr: {mongo_addr}")
+        setting = load_setting()
+        client = pymongo.MongoClient(setting.mongo_addr)
+        print(f"Mongo addr: {setting.mongo_addr}")
         for i, db in enumerate(Corps.get_all_corps()):
             print(f'{i+1}. Cleaning c106 collection in {db} db.')
             try:
