@@ -3,7 +3,6 @@ import pickle
 import platform
 
 import logging
-
 import pymongo.errors
 
 logger = logging.getLogger(__name__)
@@ -66,21 +65,21 @@ def load() -> DbSetting:
             return s
 
 
-def chg_mongo_addr(addr: str):
+def chg_mongo_addr(new_addr: str):
     """몽고 db의 주소 변경
 
     몽고 db의 주소를 변경하는 함수로 형식을 검사하여 적합하면 변경함.
     """
-    if addr.startswith('mongodb://'):
+    if new_addr.startswith('mongodb://'):
         s = load()
         before = s.mongo_addr
-        s.mongo_addr = addr
+        s.mongo_addr = new_addr
         if before != s.mongo_addr:
-            print(f'Change mongo setting : {before} -> {addr}')
-        with open(FULL_PATH, "wb") as fw:
-            pickle.dump(s, fw)
+            print(f'Change mongo setting : {before} -> {new_addr}')
+            with open(FULL_PATH, "wb") as fw:
+                pickle.dump(s, fw)
     else:
-        raise ValueError(f'Invalid mongo address : {addr}')
+        raise ValueError(f'Invalid mongo address : {new_addr}')
 
 
 def turn_off_mongo():
